<!--
SPDX-FileCopyrightText: 2025 Ivan Perevala <ivan95perevala@gmail.com>

SPDX-License-Identifier: GPL-3.0-or-later
-->

# UI components for Blender extensions

[![PyPI](https://img.shields.io/pypi/v/bhqui.svg)](https://pypi.org/project/bhqui/)
[![Status](https://img.shields.io/pypi/status/bhqui.svg)](https://pypi.org/project/bhqui/)
[![License: GPL-3.0-or-later](https://img.shields.io/badge/license-GPLv3-yellow.svg)](https://www.gnu.org/licenses/gpl-3.0-standalone.html)
[![Documentation Status](https://readthedocs.org/projects/lib-bhqui/badge/?version=latest)](https://lib-bhqui.readthedocs.io/latest)
[![Spell Check](https://github.com/ivan-perevala/lib_bhqui/actions/workflows/spellcheck.yml/badge.svg)](https://github.com/ivan-perevala/lib_bhqui/actions/workflows/spellcheck.yml)

<p align="center">
    <img src="https://raw.githubusercontent.com/ivan-perevala/lib_bhqui/main/.github/images/logo-dark.svg" alt="Logo" style="width:50%; height:auto;">
</p>

This module is a collection of utility functionality for UI elements in the Blender extensions.
It includes functions for unique naming, text wrapping, developer extras, progress handling,
icon caching, and preset management.

Links:

* Documentation: [lib-bhqui.readthedocs.io/latest](https://lib-bhqui.readthedocs.io/latest/)

* Project is [available on PyPI](https://pypi.org/project/bhqui/):

    ```powershell
    pip install bhqui
    ```

© 2025 Ivan Perevala (ivan95perevala@gmail.com)
